==> xreview_0.96.zip: xreview/language/japanese/main.php <==
<?php
  define("_MB_POSTED","ӥ塼ɲäޤ");
  define("_MB_REVIEW_POSTED","ӥ塼ɲäޤ");
  define("_MB_REVIEW_DELETE_POSTED","ӥ塼ޤ");
  define("_MB_REVIEW_UPDATE_POSTED","ӥ塼򹹿ޤ");
  define("_MB_REVIEW_FAILURE_POSTED","ӥ塼ɲä˼Ԥޤ");
  define("_MB_REVIEWSET_POSTED","ӥ塼åȤɲäޤ");
  define("_MB_REVIEWSET_DELETE_POSTED","ӥ塼åȤޤ");
  define("_MB_REVIEWSET_UPDATE_POSTED","ӥ塼åȤ򹹿ޤ");
  define("_MB_AUTH_UPDATE_POSTED","¤򹹿ޤ");
  define("_MB_URI_LINKFLAG_UPDATE_POSTED","󥯥ե饰򹹿ޤ");
  define("_MB_URI_UPDATE_POSTED","գңɾ򹹿ޤ");

  define("_MB_ILLEGAL_ACCESS","");

  define("_MB_LABEL_REVIEW_LIST_SUBJECT","ӥ塼åȰ");
  define("_MB_LABEL_REVIEW_VIEW_SUBJECT","ӥ塼");
  define("_MB_LABEL_REVIEW_FORM_SUBJECT","ӥ塼");
  define("_MB_LABEL_REVIEW_FORM_COMMENT","ȡ");
  define("_MB_LABEL_REVIEW_FORM_POINT","ɾ&nbsp;&nbsp;&nbsp;");
  define("_MB_LABEL_REVIEW_FORM_POINT_NOTE","(10)");
  define("_MB_LABEL_RETURN_LIST","ؤɤ");
  define("_MB_LABEL_USER","桼");
  define("_MB_LABEL_REVIEW_FORM_ADD","ӥ塼ɲ");
  define("_MB_LABEL_REVIEW_FORM_EDIT","Խ");
  define("_MB_LABEL_REVIEW_FORM_CANCEL","󥻥");

  //ӥ塼åȴ@admin
  define("_MB_ADMIN_REVIEWSET_EDIT","ӥ塼åԽ");
  define("_MB_ADMIN_REVIEWSET_DEL","ӥ塼åȺ");
  define("_MB_ADMIN_REVIEWSET_ID","ID");
  define("_MB_ADMIN_REVIEWSET_NAME","ӥ塼å̾ ");
  define("_MB_ADMIN_REVIEWSET_INFO","ӥ塼å");
  define("_MB_ADMIN_REVIEWSET_TARGET","оݥӥ塼");
  define("_MB_ADMIN_REVIEWSET_FUNCTIONS_LABEL","ǽ");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_EDIT","Խ");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_DEL","");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_UPDATE","");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_ADD","ӥ塼åɲ");



  //URI@admin
  define("_MB_ADMIN_URI_ID_LABEL","ID");
  define("_MB_ADMIN_URI_URI_LABEL","URI");
  define("_MB_ADMIN_URI_LINK_FLAG_LABEL","󥯵 ");
  define("_MB_ADMIN_URI_FUNCTIONS_LABEL","ǽ(ӥ塼)");
  define("_MB_ADMIN_URI_FUNCTION_DETAILE","URIܺ");
  define("_MB_ADMIN_URI_FUNCTION_UPDATE","");
  define("_MB_ADMIN_URI_LINK_PERMISSION","Ĥ");

  define("_MB_ADMIN_URI_NAME","գң̾");
  define("_MB_ADMIN_REVIEWLIST","ӥ塼");
  define("_MB_ADMIN_REVIEW_ID","ID");
  define("_MB_ADMIN_REVIEW_USER","桼");
  define("_MB_ADMIN_REVIEW_INFO","ӥ塼");
  define("_MB_ADMIN_REVIEW_POINT","ɾ");
  define("_MB_ADMIN_REVIEW_POINT_NOTE","(10)");
  define("_MB_ADMIN_REVIEW_FUNCTIONS_LABEL","ǽ");
  define("_MB_ADMIN_REVIEW_FUNCTION_EDIT","Խ");
  define("_MB_ADMIN_REVIEW_FUNCTION_DEL","");
  define("_MB_ADMIN_REVIEW_FUNCTION_DEL_CONFIRM","ӥ塼ǧ");

  //ӥ塼Խ@admin
  define("_MB_ADMIN_REVIEW_EDIT","ӥ塼Խ");
  define("_MB_ADMIN_REVIEW_FUNCTION_UPDATE","");

  //´@admin
  define("_MB_ADMIN_AUTH_GROUP_LABEL","ϤĤ륰롼:");
  define("_MB_ADMIN_AUTH_FUNCTION_UPDATE","");

	//
  define("_MB_ADMIN_TITLE","");

?>

==> xreview_0.97.zip: xreview/language/japanese/main.php <==
<?php
  define("_MB_POSTED","ӥ塼ɲäޤ");
  define("_MB_REVIEW_POSTED","ӥ塼ɲäޤ");
  define("_MB_REVIEW_DELETE_POSTED","ӥ塼ޤ");
  define("_MB_REVIEW_UPDATE_POSTED","ӥ塼򹹿ޤ");
  define("_MB_REVIEW_FAILURE_POSTED","ӥ塼ɲä˼Ԥޤ");
  define("_MB_REVIEWSET_POSTED","ӥ塼åȤɲäޤ");
  define("_MB_REVIEWSET_DELETE_POSTED","ӥ塼åȤޤ");
  define("_MB_REVIEWSET_UPDATE_POSTED","ӥ塼åȤ򹹿ޤ");
  define("_MB_AUTH_UPDATE_POSTED","¤򹹿ޤ");
  define("_MB_URI_LINKFLAG_UPDATE_POSTED","󥯥ե饰򹹿ޤ");
  define("_MB_URI_UPDATE_POSTED","գңɾ򹹿ޤ");
  define("_MB_URI_DELETE_POSTED","գңɾȴϢӥ塼ޤ");

  define("_MB_ERR_HEAD","Υ顼ΤǡϿǤޤǤ");
  define("_MB_ERR_REVIEW_COMMENT","ӥ塼Ĺޤ");
  define("_MB_ERR_REVIEW_TITLE","ӥ塼оݤΥڡΥȥ뤬Ĺޤ");
  define("_MB_ERR_REVIEW_POINT","ɾ");
  define("_MB_ERR_REVIEW_URI","ӥ塼оݤΥڡURIĹޤ");
  define("_MB_ERR_REVIEW_EXPLANATION","ӥ塼оݤΥڡʸĹޤ");

  define("_MB_ERR_DATABASE","ǡ١ι˼Ԥޤ");

  define("_MB_ILLEGAL_ACCESS","");

  define("_MB_XREVIEW_CANCEL","󥻥");

  define("_MB_LABEL_REVIEW_LIST_SUBJECT","ӥ塼åȰ");
  define("_MB_LABEL_REVIEW_VIEW_SUBJECT","ӥ塼");
  define("_MB_LABEL_REVIEW_FORM_SUBJECT","ӥ塼");
  define("_MB_LABEL_REVIEW_FORM_COMMENT","ȡ");
  define("_MB_LABEL_REVIEW_FORM_POINT","ɾ&nbsp;&nbsp;&nbsp;");
  define("_MB_LABEL_REVIEW_FORM_POINT_NOTE","(10)");
  define("_MB_LABEL_RETURN_LIST","ؤɤ");
  define("_MB_LABEL_USER","桼");
  define("_MB_LABEL_REVIEW_FORM_ADD","ӥ塼ɲ");
  define("_MB_LABEL_REVIEW_FORM_EDIT","Խ");
  define("_MB_LABEL_REVIEW_FORM_CANCEL","󥻥");

  //ӥ塼åȴ@admin
  define("_MB_ADMIN_REVIEWSET_EDIT","ӥ塼åԽ");
  define("_MB_ADMIN_REVIEWSET_DEL","ӥ塼åȺ");
  define("_MB_ADMIN_REVIEWSET_ID","ID");
  define("_MB_ADMIN_REVIEWSET_NAME","ӥ塼å̾ ");
  define("_MB_ADMIN_REVIEWSET_INFO","ӥ塼å");
  define("_MB_ADMIN_REVIEWSET_TARGET","оݥӥ塼");
  define("_MB_ADMIN_REVIEWSET_FUNCTIONS_LABEL","ǽ");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_EDIT","Խ");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_DEL","");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_UPDATE","");
  define("_MB_ADMIN_REVIEWSET_FUNCTION_ADD","ӥ塼åɲ");



  //URI@admin
  define("_MB_ADMIN_URI_ID_LABEL","ID");
  define("_MB_ADMIN_URI_URI_LABEL","URI");
  define("_MB_ADMIN_URI_LINK_FLAG_LABEL","󥯵 ");
  define("_MB_ADMIN_URI_FUNCTIONS_LABEL","ǽ(ӥ塼)");
  define("_MB_ADMIN_URI_FUNCTION_DETAILE","URIܺ");
  define("_MB_ADMIN_URI_FUNCTION_UPDATE","");
  define("_MB_ADMIN_URI_FUNCTION_DEL","");
  define("_MB_ADMIN_URI_FUNCTION_DEL_NOTE","Ϣ벼Υǡƺޤ");
  define("_MB_ADMIN_URI_LINK_PERMISSION","Ĥ");
  define("_MB_ADMIN_URI_EXPLANATION","ʸ");

  define("_MB_ADMIN_URI_NAME","գң̾");
  define("_MB_ADMIN_REVIEWLIST","ӥ塼");
  define("_MB_ADMIN_REVIEW_ID","ID");
  define("_MB_ADMIN_REVIEW_USER","桼");
  define("_MB_ADMIN_REVIEW_INFO","ӥ塼");
  define("_MB_ADMIN_REVIEW_POINT","ɾ");
  define("_MB_ADMIN_REVIEW_POINT_NOTE","(10)");
  define("_MB_ADMIN_REVIEW_FUNCTIONS_LABEL","ǽ");
  define("_MB_ADMIN_REVIEW_FUNCTION_EDIT","Խ");
  define("_MB_ADMIN_REVIEW_FUNCTION_DEL","");
  define("_MB_ADMIN_REVIEW_FUNCTION_DEL_CONFIRM","ӥ塼ǧ");

  //ӥ塼Խ@admin
  define("_MB_ADMIN_REVIEW_EDIT","ӥ塼Խ");
  define("_MB_ADMIN_REVIEW_FUNCTION_UPDATE","");

  //´@admin
  define("_MB_ADMIN_AUTH_GROUP_LABEL","ϤĤ륰롼:");
  define("_MB_ADMIN_AUTH_FUNCTION_UPDATE","");

	//
  define("_MB_ADMIN_TITLE","");

?>
